/**
Lowercase the keys of an object.

@returns A new object with the keys lowercased.

@example
```
import lowercaseKeys = require('lowercase-keys');

lowercaseKeys({FOO: true, bAr: false});
//=> {foo: true, bar: false}
```
*/
declare function lowercaseKeys<T extends unknown>(object: {[key: string]: T}): {[key: string]: T};

export = lowercaseKeys;
